"""This file contains constants used by pymemuc."""
from os import name

# check if running on windows
WIN32 = name == "nt"

# check for windows registry support
if WIN32:
    try:
        # flake8: noqa
        # pylint: disable=unused-import
        import winreg  # noqa

        WINREG_EN = True
    except ImportError:
        WINREG_EN = False
else:
    WINREG_EN = False

# number of times to retry a command decorated with _decorator._retryable
RETRIES = 3



"""PyMemuc exceptions module"""

from subprocess import TimeoutExpired


class PyMemucError(Exception):
    """PyMemuc error class"""

    def __init__(self, value) -> None:
        self.value = value

    def __str__(self) -> str:
        return repr(self.value)


class PyMemucException(Exception):
    """PyMemuc exception class"""

    def __init__(self, value) -> None:
        self.value = value

    def __str__(self) -> str:
        return repr(self.value)


class PyMemucIndexError(PyMemucException):
    """PyMemuc index error class"""

    def __init__(self, value) -> None:
        self.value = value

    def __str__(self) -> str:
        return repr(self.value)


class PyMemucTimeoutExpired(TimeoutExpired):
    """PyMemuc timeout error class"""

    def __init__(self, value) -> None:
        self.value = value

    def __str__(self) -> str:
        return repr(self.value)
